# Nicotine+ Team

## Active

### Mat (mathiascode)
 - Maintainer (2020–present)
 - Developer

### eLvErDe
 - Maintainer (2013–2016)
 - Domain name administrator
 - Source code migration from SVN to GitHub
 - Developer

### Han Boetes
 - Tester
 - Documentation
 - Bug hunting
 - Translation management

### alekksander
 - Tester
 - Redesign of some graphics

### slook
 - Tester
 - Accessibility improvements

## Inactive

### daelstorm
 - Maintainer (2004–2009)
 - Developer

### quinox
 - Maintainer (2009–2012)
 - Developer

### Michael Labouebe (gfarmerfr)
 - Maintainer (2016–2017)
 - Developer

### Kip Warner
 - Maintainer (2018–2020)
 - Developer
 - Debianization

### gallows (aka 'burp O')
 - Developer
 - Packager
 - Submitted Slack.Build file

### hedonist (formerly known as alexbk)
 - OS X Nicotine.app maintainer / developer
 - Author of PySoulSeek, used for Nicotine core

### lee8oi
 - Bash commander
 - New and updated /alias

### INMCM
 - Nicotine+ topic maintainer on [ubuntuforums.org](https://ubuntuforums.org/showthread.php?t=196835)

### suser-guru
 - Suse Linux packager
 - Nicotine+ RPM's for Suse 9.1, 9.2, 9.3, 10.0, 10.1

### osiris
 - Handy-man
 - Documentation
 - Some GNU/Linux packaging
 - Nicotine+ on Win32
 - Author of Nicotine+ guide

### Mutnick
 - Created Nicotine+ GitHub organization
 - Developer

### Lene Preuss
 - Python 3 migration
 - Unit and DEP-8 continuous integration testing

---

# Nicotine Team

### Ingmar K. Steen (Hyriand)
 - Maintainer (2003–2004)

### daelstorm
 - Beta tester
 - Designer of most of the settings
 - Made the Nicotine icons

### SmackleFunky
 - Beta tester

### Wretched
 - Beta tester
 - Bringer of great ideas

### (va)\*10^3
 - Beta tester
 - Designer of Nicotine homepage and artwork (logos)

### sierracat
 - MacOSX tester
 - soulseeX developer

### Gustavo J. A. M. Carneiro
 - Created the exception dialog

### SeeSchloss
 - Developer
 - Created 1.0.8 Win32 installer
 - Created [Soulfind](https://github.com/seeschloss/soulfind), open source Soulseek server written in D

### vasi
 - Mac developer
 - Packaged Nicotine on OSX PowerPC

---

# PySoulSeek Contributors

### Alexander Kanavin
 - Maintainer (2001–2003)

### Nir Arbel
 - Helped with many protocol questions I had, and of
   course he designed and implemented the whole
   system.

### Brett W. Thompson (Zip)
 - I used his client code to get an initial impression
   of how the system works.
 - Supplied the patch for logging chat conversations.

### Josselin Mouette
 - Official Debian package maintainer

### blueboy
 - Former unofficial Debian package maintainer

### Christian Swinehart
 - Fink package maintainer

### Ingmar K. Steen (Hyriand)
 - Patches for upload bandwidth management, banning,
   various UI improvements and more

### Geert Kloosterman
 - A script for importing Windows Soulseek configuration

### Joe Halliwell
 - Submitted a patch for optionally discarding search
   results after closing a search tab

### Alexey Vyskubov
 - Code cleanups

### Jason Green (SmackleFunky)
 - Ignore list and auto-join checkbox, wishlists

---

# Third-Party Attributions

 - This program includes IP2Location LITE data available from:  
   https://lite.ip2location.com

 - Country flags licensed under the MIT License.  
   Copyright (c) 2016–2017 Bowtie AB  
   Copyright (c) 2018–2020 Jack Marsh  
   https://github.com/jackiboy/flagpack

 - tinytag licensed under the MIT License.  
   Copyright (c) 2014–2022 Tom Wallroth  
   https://github.com/devsnd/tinytag/
